@@ -9,13 +9,13 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 	 * the common boiler plate for every action. It is triggered by the
 	 * underlying framework.
 	 */
-	public function firstAction() {
+	public function firstAction(): void {
 		if (!FreshRSS_Auth::hasAccess()) {
 			// Token is useful in the case that anonymous refresh is forbidden
 			// and CRON task cannot be used with php command so the user can
 			// set a CRON task to refresh his feeds by using token inside url
 			$token = FreshRSS_Context::$user_conf->token;
-			$token_param = Minz_Request::param('token', '');
+			$token_param = Minz_Request::paramString('token');
 			$token_is_ok = ($token != '' && $token == $token_param);
 			$action = Minz_Request::actionName();
 			$allow_anonymous_refresh = FreshRSS_Context::$system_conf->allow_anonymous_refresh;
@@ -27,48 +27,47 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 	}
 
 	/**
-	 * @param string $url
-	 * @param string $title
-	 * @param int $cat_id
-	 * @param string $new_cat_name
-	 * @param string $http_auth
-	 * @return FreshRSS_Feed
+	 * @param array<string,mixed> $attributes
 	 * @throws FreshRSS_AlreadySubscribed_Exception
 	 * @throws FreshRSS_FeedNotAdded_Exception
 	 * @throws FreshRSS_Feed_Exception
 	 * @throws Minz_FileNotExistException
 	 */
-	public static function addFeed($url, $title = '', $cat_id = 0, $new_cat_name = '', $http_auth = '', $attributes = array(), $kind = FreshRSS_Feed::KIND_RSS) {
+	public static function addFeed(string $url, string $title = '', int $cat_id = 0, string $new_cat_name = '',
+		string $http_auth = '', array $attributes = [], int $kind = FreshRSS_Feed::KIND_RSS): FreshRSS_Feed {
 		FreshRSS_UserDAO::touch();
-		@set_time_limit(300);
+		if (function_exists('set_time_limit')) {
+			@set_time_limit(300);
+		}
 
 		$catDAO = FreshRSS_Factory::createCategoryDao();
 
 		$url = trim($url);
 
 		/** @var string|null $url */
-		$url = Minz_ExtensionManager::callHook('check_url_before_add', $url);
-		if (null === $url) {
+		$urlHooked = Minz_ExtensionManager::callHook('check_url_before_add', $url);
+		if ($urlHooked === null) {
 			throw new FreshRSS_FeedNotAdded_Exception($url);
 		}
+		$url = $urlHooked;
 
 		$cat = null;
 		if ($cat_id > 0) {
 			$cat = $catDAO->searchById($cat_id);
 		}
-		if ($cat == null && $new_cat_name != '') {
-			$new_cat_id = $catDAO->addCategory(array('name' => $new_cat_name));
+		if ($cat === null && $new_cat_name != '') {
+			$new_cat_id = $catDAO->addCategory(['name' => $new_cat_name]);
 			$cat_id = $new_cat_id > 0 ? $new_cat_id : $cat_id;
 			$cat = $catDAO->searchById($cat_id);
 		}
-		if ($cat == null) {
+		if ($cat === null) {
 			$catDAO->checkDefault();
 		}
-		$cat_id = $cat == null ? FreshRSS_CategoryDAO::DEFAULTCATEGORYID : $cat->id();
+		$cat_id = $cat === null ? FreshRSS_CategoryDAO::DEFAULTCATEGORYID : $cat->id();
 
 		$feed = new FreshRSS_Feed($url);	//Throws FreshRSS_BadUrl_Exception
 		$title = trim($title);
-		if ($title != '') {
+		if ($title !== '') {
 			$feed->_name($title);
 		}
 		$feed->_kind($kind);
@@ -130,23 +129,23 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 	 *
 	 * If url_rss is false, nothing happened.
 	 */
-	public function addAction() {
-		$url = Minz_Request::param('url_rss');
+	public function addAction(): void {
+		$url = Minz_Request::paramString('url_rss');
 
-		if ($url === false) {
+		if ($url === '') {
 			// No url, do nothing
-			Minz_Request::forward(array(
+			Minz_Request::forward([
 				'c' => 'subscription',
-				'a' => 'index'
-			), true);
+				'a' => 'index',
+			], true);
 		}
 
 		$feedDAO = FreshRSS_Factory::createFeedDao();
-		$url_redirect = array(
+		$url_redirect = [
 			'c' => 'subscription',
 			'a' => 'add',
-			'params' => array(),
-		);
+			'params' => [],
+		];
 
 		$limits = FreshRSS_Context::$system_conf->limits;
 		$this->view->feeds = $feedDAO->listFeeds();
@@ -155,27 +154,27 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 		}
 
 		if (Minz_Request::isPost()) {
-			$cat = Minz_Request::param('category');
+			$cat = Minz_Request::paramInt('category');
 
 			// HTTP information are useful if feed is protected behind a
 			// HTTP authentication
-			$user = trim(Minz_Request::param('http_user', ''));
-			$pass = trim(Minz_Request::param('http_pass', ''));
+			$user = Minz_Request::paramString('http_user');
+			$pass = Minz_Request::paramString('http_pass');
 			$http_auth = '';
 			if ($user != '' && $pass != '') {	//TODO: Sanitize
 				$http_auth = $user . ':' . $pass;
 			}
 
-			$cookie = Minz_Request::param('curl_params_cookie', '');
+			$cookie = Minz_Request::paramString('curl_params_cookie');
 			$cookie_file = Minz_Request::paramBoolean('curl_params_cookiefile');
-			$max_redirs = intval(Minz_Request::param('curl_params_redirects', 0));
-			$useragent = Minz_Request::param('curl_params_useragent', '');
-			$proxy_address = Minz_Request::param('curl_params', '');
-			$proxy_type = Minz_Request::param('proxy_type', '');
+			$max_redirs = Minz_Request::paramInt('curl_params_redirects');
+			$useragent = Minz_Request::paramString('curl_params_useragent');
+			$proxy_address = Minz_Request::paramString('curl_params');
+			$proxy_type = Minz_Request::paramString('proxy_type');
 			$opts = [];
 			if ($proxy_type !== '') {
 				$opts[CURLOPT_PROXY] = $proxy_address;
-				$opts[CURLOPT_PROXYTYPE] = intval($proxy_type);
+				$opts[CURLOPT_PROXYTYPE] = (int)$proxy_type;
 			}
 			if ($cookie !== '') {
 				$opts[CURLOPT_COOKIE] = $cookie;
@@ -185,7 +184,7 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 				// without reading any existing cookie data.
 				$opts[CURLOPT_COOKIEFILE] = '';
 			}
-			if ($max_redirs != 0) {
+			if ($max_redirs !== 0) {
 				$opts[CURLOPT_MAXREDIRS] = $max_redirs;
 				$opts[CURLOPT_FOLLOWLOCATION] = 1;
 			}
@@ -193,29 +192,49 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 				$opts[CURLOPT_USERAGENT] = $useragent;
 			}
 
-			$attributes = array(
-				'ssl_verify' => null,
-				'timeout' => null,
+			$attributes = [
 				'curl_params' => empty($opts) ? null : $opts,
-			);
+			];
 			$attributes['ssl_verify'] = Minz_Request::paramTernary('ssl_verify');
-			$timeout = intval(Minz_Request::param('timeout', 0));
+			$timeout = Minz_Request::paramInt('timeout');
 			$attributes['timeout'] = $timeout > 0 ? $timeout : null;
 
-			$feed_kind = (int)Minz_Request::param('feed_kind', FreshRSS_Feed::KIND_RSS);
+			$feed_kind = Minz_Request::paramInt('feed_kind') ?: FreshRSS_Feed::KIND_RSS;
 			if ($feed_kind === FreshRSS_Feed::KIND_HTML_XPATH || $feed_kind === FreshRSS_Feed::KIND_XML_XPATH) {
 				$xPathSettings = [];
-				if (Minz_Request::param('xPathFeedTitle', '') != '') $xPathSettings['feedTitle'] = Minz_Request::param('xPathFeedTitle', '', true);
-				if (Minz_Request::param('xPathItem', '') != '') $xPathSettings['item'] = Minz_Request::param('xPathItem', '', true);
-				if (Minz_Request::param('xPathItemTitle', '') != '') $xPathSettings['itemTitle'] = Minz_Request::param('xPathItemTitle', '', true);
-				if (Minz_Request::param('xPathItemContent', '') != '') $xPathSettings['itemContent'] = Minz_Request::param('xPathItemContent', '', true);
-				if (Minz_Request::param('xPathItemUri', '') != '') $xPathSettings['itemUri'] = Minz_Request::param('xPathItemUri', '', true);
-				if (Minz_Request::param('xPathItemAuthor', '') != '') $xPathSettings['itemAuthor'] = Minz_Request::param('xPathItemAuthor', '', true);
-				if (Minz_Request::param('xPathItemTimestamp', '') != '') $xPathSettings['itemTimestamp'] = Minz_Request::param('xPathItemTimestamp', '', true);
-				if (Minz_Request::param('xPathItemTimeFormat', '') != '') $xPathSettings['itemTimeFormat'] = Minz_Request::param('xPathItemTimeFormat', '', true);
-				if (Minz_Request::param('xPathItemThumbnail', '') != '') $xPathSettings['itemThumbnail'] = Minz_Request::param('xPathItemThumbnail', '', true);
-				if (Minz_Request::param('xPathItemCategories', '') != '') $xPathSettings['itemCategories'] = Minz_Request::param('xPathItemCategories', '', true);
-				if (Minz_Request::param('xPathItemUid', '') != '') $xPathSettings['itemUid'] = Minz_Request::param('xPathItemUid', '', true);
+				if (Minz_Request::paramString('xPathFeedTitle') !== '') {
+					$xPathSettings['feedTitle'] = Minz_Request::paramString('xPathFeedTitle', true);
+				}
+				if (Minz_Request::paramString('xPathItem') !== '') {
+					$xPathSettings['item'] = Minz_Request::paramString('xPathItem', true);
+				}
+				if (Minz_Request::paramString('xPathItemTitle') !== '') {
+					$xPathSettings['itemTitle'] = Minz_Request::paramString('xPathItemTitle', true);
+				}
+				if (Minz_Request::paramString('xPathItemContent') !== '') {
+					$xPathSettings['itemContent'] = Minz_Request::paramString('xPathItemContent', true);
+				}
+				if (Minz_Request::paramString('xPathItemUri') !== '') {
+					$xPathSettings['itemUri'] = Minz_Request::paramString('xPathItemUri', true);
+				}
+				if (Minz_Request::paramString('xPathItemAuthor') !== '') {
+					$xPathSettings['itemAuthor'] = Minz_Request::paramString('xPathItemAuthor', true);
+				}
+				if (Minz_Request::paramString('xPathItemTimestamp') !== '') {
+					$xPathSettings['itemTimestamp'] = Minz_Request::paramString('xPathItemTimestamp', true);
+				}
+				if (Minz_Request::paramString('xPathItemTimeFormat') !== '') {
+					$xPathSettings['itemTimeFormat'] = Minz_Request::paramString('xPathItemTimeFormat', true);
+				}
+				if (Minz_Request::paramString('xPathItemThumbnail') !== '') {
+					$xPathSettings['itemThumbnail'] = Minz_Request::paramString('xPathItemThumbnail', true);
+				}
+				if (Minz_Request::paramString('xPathItemCategories') !== '') {
+					$xPathSettings['itemCategories'] = Minz_Request::paramString('xPathItemCategories', true);
+				}
+				if (Minz_Request::paramString('xPathItemUid') !== '') {
+					$xPathSettings['itemUid'] = Minz_Request::paramString('xPathItemUid', true);
+				}
 				if (!empty($xPathSettings)) {
 					$attributes['xpath'] = $xPathSettings;
 				}
@@ -226,19 +245,24 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 			} catch (FreshRSS_BadUrl_Exception $e) {
 				// Given url was not a valid url!
 				Minz_Log::warning($e->getMessage());
-				return Minz_Request::bad(_t('feedback.sub.feed.invalid_url', $url), $url_redirect);
+				Minz_Request::bad(_t('feedback.sub.feed.invalid_url', $url), $url_redirect);
+				return;
 			} catch (FreshRSS_Feed_Exception $e) {
 				// Something went bad (timeout, server not found, etc.)
 				Minz_Log::warning($e->getMessage());
-				return Minz_Request::bad(_t('feedback.sub.feed.internal_problem', _url('index', 'logs')), $url_redirect);
+				Minz_Request::bad(_t('feedback.sub.feed.internal_problem', _url('index', 'logs')), $url_redirect);
+				return;
 			} catch (Minz_FileNotExistException $e) {
 				// Cache directory doesn’t exist!
 				Minz_Log::error($e->getMessage());
-				return Minz_Request::bad(_t('feedback.sub.feed.internal_problem', _url('index', 'logs')), $url_redirect);
+				Minz_Request::bad(_t('feedback.sub.feed.internal_problem', _url('index', 'logs')), $url_redirect);
+				return;
 			} catch (FreshRSS_AlreadySubscribed_Exception $e) {
-				return Minz_Request::bad(_t('feedback.sub.feed.already_subscribed', $e->feedName()), $url_redirect);
+				Minz_Request::bad(_t('feedback.sub.feed.already_subscribed', $e->feedName()), $url_redirect);
+				return;
 			} catch (FreshRSS_FeedNotAdded_Exception $e) {
-				return Minz_Request::bad(_t('feedback.sub.feed.not_added', $e->url()), $url_redirect);
+				Minz_Request::bad(_t('feedback.sub.feed.not_added', $e->url()), $url_redirect);
+				return;
 			}
 
 			// Entries are in DB, we redirect to feed configuration page.
@@ -250,7 +274,7 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 			FreshRSS_View::prependTitle(_t('sub.feed.title_add') . ' · ');
 
 			$catDAO = FreshRSS_Factory::createCategoryDao();
-			$this->view->categories = $catDAO->listCategories(false);
+			$this->view->categories = $catDAO->listCategories(false) ?: [];
 			$this->view->feed = new FreshRSS_Feed($url);
 			try {
 				// We try to get more information about the feed.
@@ -278,13 +302,13 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 	 * Parameter is:
 	 *   - id (default: false)
 	 */
-	public function truncateAction() {
-		$id = Minz_Request::param('id');
-		$url_redirect = array(
+	public function truncateAction(): void {
+		$id = Minz_Request::paramInt('id');
+		$url_redirect = [
 			'c' => 'subscription',
 			'a' => 'index',
-			'params' => array('id' => $id)
-		);
+			'params' => ['id' => $id],
+		];
 
 		if (!Minz_Request::isPost()) {
 			Minz_Request::forward($url_redirect, true);
@@ -302,15 +326,14 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 	}
 
 	/**
-	 * @param int $feed_id
-	 * @param string $feed_url
-	 * @param bool $force
-	 * @param SimplePie|null $simplePiePush
-	 * @param bool $noCommit
-	 * @param int $maxFeeds
+	 * @return array{0:int,1:FreshRSS_Feed|false,2:int}
+	 * @throws FreshRSS_BadUrl_Exception
 	 */
-	public static function actualizeFeed($feed_id, $feed_url, $force, $simplePiePush = null, $noCommit = false, $maxFeeds = 10) {
-		@set_time_limit(300);
+	public static function actualizeFeed(int $feed_id, string $feed_url, bool $force, ?SimplePie $simplePiePush = null,
+		bool $noCommit = false, int $maxFeeds = 10): array {
+		if (function_exists('set_time_limit')) {
+			@set_time_limit(300);
+		}
 
 		$feedDAO = FreshRSS_Factory::createFeedDao();
 		$entryDAO = FreshRSS_Factory::createEntryDao();
@@ -318,7 +341,7 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 		// Create a list of feeds to actualize.
 		// If feed_id is set and valid, corresponding feed is added to the list but
 		// alone in order to automatize further process.
-		$feeds = array();
+		$feeds = [];
 		if ($feed_id > 0 || $feed_url) {
 			$feed = $feed_id > 0 ? $feedDAO->searchById($feed_id) : $feedDAO->searchByUrl($feed_url);
 			if ($feed) {
@@ -329,7 +352,7 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 		}
 
 		// Set maxFeeds to a minimum of 10
-		if (!is_int($maxFeeds) || $maxFeeds < 10) {
+		if ($maxFeeds < 10) {
 			$maxFeeds = 10;
 		}
 
@@ -349,30 +372,31 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 			$url = $feed->url();	//For detection of HTTP 301
 
 			$pubSubHubbubEnabled = $pubsubhubbubEnabledGeneral && $feed->pubSubHubbubEnabled();
-			if ((!$simplePiePush) && (!$feed_id) && $pubSubHubbubEnabled && ($feed->lastUpdate() > $pshbMinAge)) {
+			if ($simplePiePush === null && $feed_id === 0 && $pubSubHubbubEnabled && ($feed->lastUpdate() > $pshbMinAge)) {
 				//$text = 'Skip pull of feed using PubSubHubbub: ' . $url;
 				//Minz_Log::debug($text);
 				//Minz_Log::debug($text, PSHB_LOG);
 				continue;	//When PubSubHubbub is used, do not pull refresh so often
 			}
 
-			$mtime = 0;
 			if ($feed->mute()) {
 				continue;	//Feed refresh is disabled
 			}
+			$mtime = $feed->cacheModifiedTime() ?: 0;
 			$ttl = $feed->ttl();
-			if ((!$simplePiePush) && (!$feed_id) &&
-				($feed->lastUpdate() + 10 >= time() - (
-					$ttl == FreshRSS_Feed::TTL_DEFAULT ? FreshRSS_Context::$user_conf->ttl_default : $ttl))) {
+			if ($ttl === FreshRSS_Feed::TTL_DEFAULT) {
+				$ttl = FreshRSS_Context::$user_conf->ttl_default;
+			}
+			if ($simplePiePush === null && $feed_id === 0 && (time() <= $feed->lastUpdate() + $ttl)) {
 				//Too early to refresh from source, but check whether the feed was updated by another user
-				$mtime = $feed->cacheModifiedTime();
-				if ($feed->lastUpdate() + 10 >= $mtime) {
+				$ε = 10;	// negligible offset errors in seconds
+				if ($mtime <= 0 ||
+					$feed->lastUpdate() + $ε >= $mtime ||
+					time() + $ε >= $mtime + FreshRSS_Context::$system_conf->limits['cache_duration']) {	// is cache still valid?
 					continue;	//Nothing newer from other users
 				}
-				//Minz_Log::debug($feed->url(false) . ' was updated at ' . date('c', $mtime) . ' by another user');
-				//Will take advantage of the newer cache
-			} else {
-				$mtime = time();
+				Minz_Log::debug('Feed ' . $feed->url(false) . ' was updated at ' . date('c', $feed->lastUpdate()) .
+					', and at ' . date('c', $mtime) . ' by another user; take advantage of newer cache.');
 			}
 
 			if (!$feed->lock()) {
@@ -380,10 +404,12 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 				continue;
 			}
 
-			$isNewFeed = $feed->lastUpdate() <= 0;
+			$feedIsNew = $feed->lastUpdate() <= 0;
+			$feedIsEmpty = false;
+			$feedIsUnchanged = false;
 
 			try {
-				if ($simplePiePush) {
+				if ($simplePiePush !== null) {
 					$simplePie = $simplePiePush;	//Used by WebSub
 				} elseif ($feed->kind() === FreshRSS_Feed::KIND_HTML_XPATH) {
 					$simplePie = $feed->loadHtmlXpath();
@@ -396,10 +422,22 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 						throw new FreshRSS_Feed_Exception('XML+XPath parsing failed for [' . $feed->url(false) . ']');
 					}
 				} else {
-					$simplePie = $feed->load(false, $isNewFeed);
+					$simplePie = $feed->load(false, $feedIsNew);
 				}
-				$newGuids = $simplePie == null ? [] : $feed->loadGuids($simplePie);
-				$entries = $simplePie == null ? [] : $feed->loadEntries($simplePie);
+
+				if ($simplePie === null) {
+					// Feed is cached and unchanged
+					$newGuids = [];
+					$entries = [];
+					$feedIsEmpty = false;	// We do not know
+					$feedIsUnchanged = true;
+				} else {
+					$newGuids = $feed->loadGuids($simplePie);
+					$entries = $feed->loadEntries($simplePie);
+					$feedIsEmpty = $simplePiePush !== null && empty($newGuids);
+					$feedIsUnchanged = false;
+				}
+				$mtime = $feed->cacheModifiedTime() ?: time();
 			} catch (FreshRSS_Feed_Exception $e) {
 				Minz_Log::warning($e->getMessage());
 				$feedDAO->updateLastUpdate($feed->id(), true);
@@ -421,16 +459,15 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 					$readWhenSameTitleInFeed = FreshRSS_Context::$user_conf->mark_when['same_title_in_feed'];
 				}
 				if ($readWhenSameTitleInFeed > 0) {
-					$titlesAsRead = array_flip($feedDAO->listTitles($feed->id(), intval($readWhenSameTitleInFeed)));
+					/** @var array<string,bool> $titlesAsRead*/
+					$titlesAsRead = array_flip($feedDAO->listTitles($feed->id(), (int)$readWhenSameTitleInFeed));
 				}
 
-				$mark_updated_article_unread = $feed->attributes('mark_updated_article_unread') !== null ? (
-						$feed->attributes('mark_updated_article_unread')
-					) : FreshRSS_Context::$user_conf->mark_updated_article_unread;
+				$mark_updated_article_unread = $feed->attributes('mark_updated_article_unread') ?? FreshRSS_Context::$user_conf->mark_updated_article_unread;
 
 				// For this feed, check existing GUIDs already in database.
-				$existingHashForGuids = $entryDAO->listHashForFeedGuids($feed->id(), $newGuids);
-				/** @var array<string,bool> */
+				$existingHashForGuids = $entryDAO->listHashForFeedGuids($feed->id(), $newGuids) ?: [];
+				/** @var array<string,bool> $newGuids */
 				$newGuids = [];
 
 				// Add entries in database if possible.
@@ -440,6 +477,7 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 						continue;	//Skip subsequent articles with same GUID
 					}
 					$newGuids[$entry->guid()] = true;
+					$entry->_lastSeen($mtime);
 
 					if (isset($existingHashForGuids[$entry->guid()])) {
 						$existingHash = $existingHashForGuids[$entry->guid()];
@@ -447,12 +485,14 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 							//This entry already exists but has been updated
 							//Minz_Log::debug('Entry with GUID `' . $entry->guid() . '` updated in feed ' . $feed->url(false) .
 								//', old hash ' . $existingHash . ', new hash ' . $entry->hash());
-							$entry->_isRead($mark_updated_article_unread ? false : null);	//Change is_read according to policy.
 							$entry->_isFavorite(null);	// Do not change favourite state
+							$entry->_isRead($mark_updated_article_unread ? false : null);	//Change is_read according to policy.
+							if ($mark_updated_article_unread) {
+								Minz_ExtensionManager::callHook('entry_auto_unread', $entry, 'updated_article');
+							}
 
-							/** @var FreshRSS_Entry|null */
 							$entry = Minz_ExtensionManager::callHook('entry_before_insert', $entry);
-							if ($entry === null) {
+							if (!($entry instanceof FreshRSS_Entry)) {
 								// An extension has returned a null value, there is nothing to insert.
 								continue;
 							}
@@ -473,15 +513,13 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 					} else {
 						$id = uTimeString();
 						$entry->_id($id);
-
 						$entry->applyFilterActions($titlesAsRead);
 						if ($readWhenSameTitleInFeed > 0) {
 							$titlesAsRead[$entry->title()] = true;
 						}
 
-						/** @var FreshRSS_Entry|null */
 						$entry = Minz_ExtensionManager::callHook('entry_before_insert', $entry);
-						if ($entry === null) {
+						if (!($entry instanceof FreshRSS_Entry)) {
 							// An extension has returned a null value, there is nothing to insert.
 							continue;
 						}
@@ -499,7 +537,7 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 						if (!$entryDAO->inTransaction()) {
 							$entryDAO->beginTransaction();
 						}
-						$entryDAO->addEntry($entry->toArray());
+						$entryDAO->addEntry($entry->toArray(), true);
 
 						if (!$entry->isRead()) {
 							$feed->incPendingUnread();
@@ -507,11 +545,18 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 						$nb_new_articles++;
 					}
 				}
+				// N.B.: Applies to _entry table and not _entrytmp:
 				$entryDAO->updateLastSeen($feed->id(), array_keys($newGuids), $mtime);
+			} elseif ($feedIsUnchanged) {
+				// Feed cache was unchanged, so mark as seen the same entries as last time
+				if (!$entryDAO->inTransaction()) {
+					$entryDAO->beginTransaction();
+				}
+				$entryDAO->updateLastSeenUnchanged($feed->id(), $mtime);
 			}
 			unset($entries);
 
-			if (mt_rand(0, 30) === 1) {	// Remove old entries once in 30.
+			if (rand(0, 30) === 1) {	// Remove old entries once in 30.
 				if (!$entryDAO->inTransaction()) {
 					$entryDAO->beginTransaction();
 				}
@@ -523,7 +568,10 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 
 			$feedDAO->updateLastUpdate($feed->id(), false, $mtime);
 			$needFeedCacheRefresh |= ($feed->keepMaxUnread() != false);
-			$needFeedCacheRefresh |= ($feed->markAsReadUponGone() != false);
+			if ($simplePiePush === null) {
+				// Do not call for WebSub events, as we do not know the list of articles still on the upstream feed.
+				$needFeedCacheRefresh |= ($feed->markAsReadUponGone($feedIsEmpty, $mtime) != false);
+			}
 			if ($needFeedCacheRefresh) {
 				$feedDAO->updateCachedValues($feed->id());
 			}
@@ -543,7 +591,7 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 						}
 						$feed->_url($selfUrl, false);
 						Minz_Log::notice('Feed ' . $url . ' canonical address moved to ' . $feed->url(false));
-						$feedDAO->updateFeed($feed->id(), array('url' => $feed->url()));
+						$feedDAO->updateFeed($feed->id(), ['url' => $feed->url()]);
 					}
 				}
 			} elseif ($feed->url() !== $url) {	// HTTP 301 Moved Permanently
@@ -553,21 +601,21 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 			}
 
 			if ($simplePie != null) {
-				if ($feed->name(true) == '') {
+				if ($feed->name(true) === '') {
 					//HTML to HTML-PRE	//ENT_COMPAT except '&'
-					$name = strtr(html_only_entity_decode($simplePie->get_title()), array('<' => '&lt;', '>' => '&gt;', '"' => '&quot;'));
+					$name = strtr(html_only_entity_decode($simplePie->get_title()), ['<' => '&lt;', '>' => '&gt;', '"' => '&quot;']);
 					$feed->_name($name);
 					$feedProperties['name'] = $feed->name(false);
 				}
-				if (trim($feed->website()) == '') {
+				if (trim($feed->website()) === '') {
 					$website = html_only_entity_decode($simplePie->get_link());
 					$feed->_website($website == '' ? $feed->url() : $website);
 					$feedProperties['website'] = $feed->website();
 					$feed->faviconPrepare();
 				}
-				if (trim($feed->description()) == '') {
+				if (trim($feed->description()) === '') {
 					$description = html_only_entity_decode($simplePie->get_description());
-					if ($description != '') {
+					if ($description !== '') {
 						$feed->_description($description);
 						$feedProperties['description'] = $feed->description();
 					}
@@ -575,7 +623,7 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 			}
 			if (!empty($feedProperties)) {
 				$ok = $feedDAO->updateFeed($feed->id(), $feedProperties);
-				if (!$ok && $isNewFeed) {
+				if (!$ok && $feedIsNew) {
 					//Cancel adding new feed in case of database error at first actualize
 					$feedDAO->deleteFeed($feed->id());
 					$feed->unlock();
@@ -614,7 +662,7 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 			$databaseDAO = FreshRSS_Factory::createDatabaseDAO();
 			$databaseDAO->minorDbMaintenance();
 		}
-		return array($updated_feeds, reset($feeds), $nb_new_articles);
+		return [$updated_feeds, reset($feeds), $nb_new_articles];
 	}
 
 	/**
@@ -628,12 +676,12 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 	 * If id and url are not specified, all the feeds are actualized. But if force is
 	 * false, process stops at 10 feeds to avoid time execution problem.
 	 */
-	public function actualizeAction() {
+	public function actualizeAction(): int {
 		Minz_Session::_param('actualize_feeds', false);
-		$id = Minz_Request::param('id');
-		$url = Minz_Request::param('url');
-		$force = Minz_Request::param('force');
-		$maxFeeds = (int)Minz_Request::param('maxFeeds');
+		$id = Minz_Request::paramInt('id');
+		$url = Minz_Request::paramString('url');
+		$force = Minz_Request::paramBoolean('force');
+		$maxFeeds = Minz_Request::paramInt('maxFeeds');
 		$noCommit = ($_POST['noCommit'] ?? 0) == 1;
 		$feed = null;
 
@@ -650,42 +698,47 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 			$databaseDAO->minorDbMaintenance();
 		} else {
 			FreshRSS_category_Controller::refreshDynamicOpmls();
-			list($updated_feeds, $feed, $nb_new_articles) = self::actualizeFeed($id, $url, $force, null, $noCommit, $maxFeeds);
+			[$updated_feeds, $feed] = self::actualizeFeed($id, $url, $force, null, $noCommit, $maxFeeds);
 		}
 
-		if (Minz_Request::param('ajax')) {
+		if (Minz_Request::paramBoolean('ajax')) {
 			// Most of the time, ajax request is for only one feed. But since
 			// there are several parallel requests, we should return that there
 			// are several updated feeds.
 			Minz_Request::setGoodNotification(_t('feedback.sub.feed.actualizeds'));
 			// No layout in ajax request.
-			$this->view->_layout(false);
-		} else {
+			$this->view->_layout(null);
+		} elseif ($feed instanceof FreshRSS_Feed) {
 			// Redirect to the main page with correct notification.
 			if ($updated_feeds === 1) {
-				Minz_Request::good(_t('feedback.sub.feed.actualized', $feed->name()), array(
-					'params' => array('get' => 'f_' . $feed->id())
-				));
+				Minz_Request::good(_t('feedback.sub.feed.actualized', $feed->name()), [
+					'params' => ['get' => 'f_' . $feed->id()]
+				]);
 			} elseif ($updated_feeds > 1) {
-				Minz_Request::good(_t('feedback.sub.feed.n_actualized', $updated_feeds), array());
+				Minz_Request::good(_t('feedback.sub.feed.n_actualized', $updated_feeds), []);
 			} else {
-				Minz_Request::good(_t('feedback.sub.feed.no_refresh'), array());
+				Minz_Request::good(_t('feedback.sub.feed.no_refresh'), []);
 			}
 		}
 		return $updated_feeds;
 	}
 
-	public static function renameFeed($feed_id, $feed_name) {
-		if ($feed_id <= 0 || $feed_name == '') {
+	/**
+	 * @throws Minz_ConfigurationNamespaceException
+	 * @throws JsonException
+	 * @throws Minz_PDOConnectionException
+	 */
+	public static function renameFeed(int $feed_id, string $feed_name): bool {
+		if ($feed_id <= 0 || $feed_name === '') {
 			return false;
 		}
 		FreshRSS_UserDAO::touch();
 		$feedDAO = FreshRSS_Factory::createFeedDao();
-		return $feedDAO->updateFeed($feed_id, array('name' => $feed_name));
+		return $feedDAO->updateFeed($feed_id, ['name' => $feed_name]) === 1;
 	}
 
-	public static function moveFeed($feed_id, $cat_id, $new_cat_name = '') {
-		if ($feed_id <= 0 || ($cat_id <= 0 && $new_cat_name == '')) {
+	public static function moveFeed(int $feed_id, int $cat_id, string $new_cat_name = ''): bool {
+		if ($feed_id <= 0 || ($cat_id <= 0 && $new_cat_name === '')) {
 			return false;
 		}
 		FreshRSS_UserDAO::touch();
@@ -693,10 +746,10 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 		$catDAO = FreshRSS_Factory::createCategoryDao();
 		if ($cat_id > 0) {
 			$cat = $catDAO->searchById($cat_id);
-			$cat_id = $cat == null ? 0 : $cat->id();
+			$cat_id = $cat === null ? 0 : $cat->id();
 		}
 		if ($cat_id <= 1 && $new_cat_name != '') {
-			$cat_id = $catDAO->addCategory(array('name' => $new_cat_name));
+			$cat_id = $catDAO->addCategory(['name' => $new_cat_name]);
 		}
 		if ($cat_id <= 1) {
 			$catDAO->checkDefault();
@@ -704,7 +757,7 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 		}
 
 		$feedDAO = FreshRSS_Factory::createFeedDao();
-		return $feedDAO->updateFeed($feed_id, array('category' => $cat_id));
+		return $feedDAO->updateFeed($feed_id, ['category' => $cat_id]) === 1;
 	}
 
 	/**
@@ -719,13 +772,13 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 	 *
 	 * @todo should handle order of the feed inside the category.
 	 */
-	public function moveAction() {
+	public function moveAction(): void {
 		if (!Minz_Request::isPost()) {
-			Minz_Request::forward(array('c' => 'subscription'), true);
+			Minz_Request::forward(['c' => 'subscription'], true);
 		}
 
-		$feed_id = Minz_Request::param('f_id');
-		$cat_id = Minz_Request::param('c_id');
+		$feed_id = Minz_Request::paramInt('f_id');
+		$cat_id = Minz_Request::paramInt('c_id');
 
 		if (self::moveFeed($feed_id, $cat_id)) {
 			// TODO: return something useful
@@ -737,7 +790,7 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 		}
 	}
 
-	public static function deleteFeed($feed_id) {
+	public static function deleteFeed(int $feed_id): bool {
 		FreshRSS_UserDAO::touch();
 		$feedDAO = FreshRSS_Factory::createFeedDao();
 		if ($feedDAO->deleteFeed($feed_id)) {
@@ -761,32 +814,25 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 	 *
 	 * Parameters are:
 	 *   - id (default: false)
-	 *   - r (default: false)
-	 * r permits to redirect to a given page at the end of this action.
-	 *
-	 * @todo handle "r" redirection in Minz_Request::forward()?
 	 */
-	public function deleteAction() {
-		$from = Minz_Request::param('from');
-		$id = Minz_Request::param('id');
+	public function deleteAction(): void {
+		$from = Minz_Request::paramString('from');
+		$id = Minz_Request::paramInt('id');
 
 		switch ($from) {
 			case 'stats':
-				$redirect_url = array('c' => 'stats', 'a' => 'idle');
+				$redirect_url = ['c' => 'stats', 'a' => 'idle'];
 				break;
 			case 'normal':
-				$get = Minz_Request::param('get');
+				$get = Minz_Request::paramString('get');
 				if ($get) {
-					$redirect_url = array('c' => 'index', 'a' => 'normal', 'params' => array('get' => $get));
+					$redirect_url = ['c' => 'index', 'a' => 'normal', 'params' => ['get' => $get]];
 				} else {
-					$redirect_url = array('c' => 'index', 'a' => 'normal');
+					$redirect_url = ['c' => 'index', 'a' => 'normal'];
 				}
 				break;
 			default:
-				$redirect_url = Minz_Request::param('r', false, true);
-				if (!$redirect_url) {
-					$redirect_url = array('c' => 'subscription', 'a' => 'index');
-				}
+				$redirect_url = ['c' => 'subscription', 'a' => 'index'];
 				if (!Minz_Request::isPost()) {
 					Minz_Request::forward($redirect_url, true);
 				}
@@ -806,23 +852,22 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 	 *   - id (mandatory - no default): Feed ID
 	 *
 	 */
-	public function clearCacheAction() {
+	public function clearCacheAction(): void {
 		//Get Feed.
-		$id = Minz_Request::param('id');
+		$id = Minz_Request::paramInt('id');
 
 		$feedDAO = FreshRSS_Factory::createFeedDao();
 		$feed = $feedDAO->searchById($id);
-
-		if (!$feed) {
-			Minz_Request::bad(_t('feedback.sub.feed.not_found'), array());
+		if ($feed === null) {
+			Minz_Request::bad(_t('feedback.sub.feed.not_found'), []);
 			return;
 		}
 
 		$feed->clearCache();
 
-		Minz_Request::good(_t('feedback.sub.feed.cache_cleared', $feed->name()), array(
-			'params' => array('get' => 'f_' . $feed->id())
-		));
+		Minz_Request::good(_t('feedback.sub.feed.cache_cleared', $feed->name()), [
+			'params' => ['get' => 'f_' . $feed->id()],
+		]);
 	}
 
 	/**
@@ -831,21 +876,23 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 	 * Parameters are:
 	 *   - id (mandatory - no default): Feed ID
 	 *
+	 * @throws FreshRSS_BadUrl_Exception
 	 */
-	public function reloadAction() {
-		@set_time_limit(300);
+	public function reloadAction(): void {
+		if (function_exists('set_time_limit')) {
+			@set_time_limit(300);
+		}
 
 		//Get Feed ID.
-		$feed_id = intval(Minz_Request::param('id', 0));
-		$limit = intval(Minz_Request::param('reload_limit', 10));
+		$feed_id = Minz_Request::paramInt('id');
+		$limit = Minz_Request::paramInt('reload_limit') ?: 10;
 
 		$feedDAO = FreshRSS_Factory::createFeedDao();
 		$entryDAO = FreshRSS_Factory::createEntryDao();
 
 		$feed = $feedDAO->searchById($feed_id);
-
-		if (!$feed) {
-			Minz_Request::bad(_t('feedback.sub.feed.not_found'), array());
+		if ($feed === null) {
+			Minz_Request::bad(_t('feedback.sub.feed.not_found'), []);
 			return;
 		}
 
@@ -876,9 +923,9 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 		Minz_ModelPdo::$usesSharedPdo = true;
 
 		//Give feedback to user.
-		Minz_Request::good(_t('feedback.sub.feed.reloaded', $feed->name()), array(
-			'params' => array('get' => 'f_' . $feed->id())
-		));
+		Minz_Request::good(_t('feedback.sub.feed.reloaded', $feed->name()), [
+			'params' => ['get' => 'f_' . $feed->id()]
+		]);
 	}
 
 	/**
@@ -889,14 +936,14 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 	 *   - selector (mandatory - no default): Selector to preview
 	 *
 	 */
-	public function contentSelectorPreviewAction() {
+	public function contentSelectorPreviewAction(): void {
 
 		//Configure.
 		$this->view->fatalError = '';
 		$this->view->selectorSuccess = false;
 		$this->view->htmlContent = '';
 
-		$this->view->_layout(false);
+		$this->view->_layout(null);
 
 		$this->_csp([
 			'default-src' => "'self'",
@@ -906,8 +953,8 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 		]);
 
 		//Get parameters.
-		$feed_id = Minz_Request::param('id');
-		$content_selector = trim(Minz_Request::param('selector'));
+		$feed_id = Minz_Request::paramInt('id');
+		$content_selector = Minz_Request::paramString('selector');
 
 		if (!$content_selector) {
 			$this->view->fatalError = _t('feedback.sub.feed.selector_preview.selector_empty');
@@ -921,9 +968,7 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 
 		//Get first entry (syntax robust for Generator or Array)
 		foreach ($entries as $myEntry) {
-			if ($entry == null) {
-				$entry = $myEntry;
-			}
+			$entry = $myEntry;
 		}
 
 		if ($entry == null) {
@@ -934,13 +979,13 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 		//Get feed.
 		$feed = $entry->feed();
 
-		if (!$feed) {
+		if ($feed === null) {
 			$this->view->fatalError = _t('feedback.sub.feed.selector_preview.no_feed');
 			return;
 		}
 
 		$attributes = $feed->attributes();
-		$attributes['path_entries_filter'] = trim(Minz_Request::param('selector_filter', '', true));
+		$attributes['path_entries_filter'] = Minz_Request::paramString('selector_filter', true);
 
 		//Fetch & select content.
 		try {
