@@ -13,10 +13,10 @@ class FreshRSS_importExport_Controller extends FreshRSS_ActionController {
 
 	/**
 	 * This action is called before every other action in that class. It is
-	 * the common boiler plate for every action. It is triggered by the
+	 * the common boilerplate for every action. It is triggered by the
 	 * underlying framework.
 	 */
-	public function firstAction() {
+	public function firstAction(): void {
 		if (!FreshRSS_Auth::hasAccess()) {
 			Minz_Error::error(403);
 		}
@@ -28,12 +28,15 @@ class FreshRSS_importExport_Controller extends FreshRSS_ActionController {
 	/**
 	 * This action displays the main page for import / export system.
 	 */
-	public function indexAction() {
+	public function indexAction(): void {
 		$this->view->feeds = $this->feedDAO->listFeeds();
 		FreshRSS_View::prependTitle(_t('sub.import_export.title') . ' · ');
 	}
 
-	private static function megabytes($size_str) {
+	/**
+	 * @return float|int|string
+	 */
+	private static function megabytes(string $size_str) {
 		switch (substr($size_str, -1)) {
 			case 'M': case 'm': return (int)$size_str;
 			case 'K': case 'k': return (int)$size_str / 1024;
@@ -42,15 +45,24 @@ class FreshRSS_importExport_Controller extends FreshRSS_ActionController {
 		return $size_str;
 	}
 
-	private static function minimumMemory($mb) {
+	/**
+	 * @param string|int $mb
+	 */
+	private static function minimumMemory($mb): void {
 		$mb = (int)$mb;
-		$ini = self::megabytes(ini_get('memory_limit'));
+		$ini = self::megabytes(ini_get('memory_limit') ?: '0');
 		if ($ini < $mb) {
 			ini_set('memory_limit', $mb . 'M');
 		}
 	}
 
-	public function importFile($name, $path, $username = null) {
+	/**
+	 * @throws FreshRSS_Zip_Exception
+	 * @throws FreshRSS_ZipMissing_Exception
+	 * @throws Minz_ConfigurationNamespaceException
+	 * @throws Minz_PDOConnectionException
+	 */
+	public function importFile(string $name, string $path, ?string $username = null): bool {
 		self::minimumMemory(256);
 
 		$this->entryDAO = FreshRSS_Factory::createEntryDao($username);
@@ -58,15 +70,15 @@ class FreshRSS_importExport_Controller extends FreshRSS_ActionController {
 
 		$type_file = self::guessFileType($name);
 
-		$list_files = array(
-			'opml' => array(),
-			'json_starred' => array(),
-			'json_feed' => array(),
-			'ttrss_starred' => array(),
-		);
+		$list_files = [
+			'opml' => [],
+			'json_starred' => [],
+			'json_feed' => [],
+			'ttrss_starred' => [],
+		];
 
 		// We try to list all files according to their type
-		$list = array();
+		$list = [];
 		if ('zip' === $type_file && extension_loaded('zip')) {
 			$zip = new ZipArchive();
 			$result = $zip->open($path);
@@ -75,6 +87,9 @@ class FreshRSS_importExport_Controller extends FreshRSS_ActionController {
 				throw new FreshRSS_Zip_Exception($result);
 			}
 			for ($i = 0; $i < $zip->numFiles; $i++) {
+				if ($zip->getNameIndex($i) === false) {
+					continue;
+				}
 				$type_zipfile = self::guessFileType($zip->getNameIndex($i));
 				if ('unknown' !== $type_zipfile) {
 					$list_files[$type_zipfile][] = $zip->getFromIndex($i);
@@ -97,6 +112,9 @@ class FreshRSS_importExport_Controller extends FreshRSS_ActionController {
 		$importService = new FreshRSS_Import_Service($username);
 
 		foreach ($list_files['opml'] as $opml_file) {
+			if ($opml_file === false) {
+				continue;
+			}
 			$importService->importOpml($opml_file);
 			if (!$importService->lastStatus()) {
 				$ok = false;
@@ -108,7 +126,7 @@ class FreshRSS_importExport_Controller extends FreshRSS_ActionController {
 			}
 		}
 		foreach ($list_files['json_starred'] as $article_file) {
-			if (!$this->importJson($article_file, true)) {
+			if (!is_string($article_file) || !$this->importJson($article_file, true)) {
 				$ok = false;
 				if (FreshRSS_Context::$isCli) {
 					fwrite(STDERR, 'FreshRSS error during JSON stars import' . "\n");
@@ -118,7 +136,7 @@ class FreshRSS_importExport_Controller extends FreshRSS_ActionController {
 			}
 		}
 		foreach ($list_files['json_feed'] as $article_file) {
-			if (!$this->importJson($article_file)) {
+			if (!is_string($article_file) || !$this->importJson($article_file)) {
 				$ok = false;
 				if (FreshRSS_Context::$isCli) {
 					fwrite(STDERR, 'FreshRSS error during JSON feeds import' . "\n");
@@ -128,8 +146,8 @@ class FreshRSS_importExport_Controller extends FreshRSS_ActionController {
 			}
 		}
 		foreach ($list_files['ttrss_starred'] as $article_file) {
-			$json = $this->ttrssXmlToJson($article_file);
-			if (!$this->importJson($json, true)) {
+			$json = is_string($article_file) ? $this->ttrssXmlToJson($article_file) : false;
+			if ($json === false || !$this->importJson($json, true)) {
 				$ok = false;
 				if (FreshRSS_Context::$isCli) {
 					fwrite(STDERR, 'FreshRSS error during TT-RSS articles import' . "\n");
@@ -151,9 +169,9 @@ class FreshRSS_importExport_Controller extends FreshRSS_ActionController {
 	 *   - file (default: nothing!)
 	 * Available file types are: zip, json or xml.
 	 */
-	public function importAction() {
+	public function importAction(): void {
 		if (!Minz_Request::isPost()) {
-			Minz_Request::forward(array('c' => 'importExport', 'a' => 'index'), true);
+			Minz_Request::forward(['c' => 'importExport', 'a' => 'index'], true);
 		}
 
 		$file = $_FILES['file'];
@@ -164,22 +182,27 @@ class FreshRSS_importExport_Controller extends FreshRSS_ActionController {
 			Minz_Request::bad(_t('feedback.import_export.file_cannot_be_uploaded'), [ 'c' => 'importExport', 'a' => 'index' ]);
 		}
 
-		@set_time_limit(300);
+		if (function_exists('set_time_limit')) {
+			@set_time_limit(300);
+		}
 
 		$error = false;
 		try {
 			$error = !$this->importFile($file['name'], $file['tmp_name']);
 		} catch (FreshRSS_ZipMissing_Exception $zme) {
-			Minz_Request::bad(_t('feedback.import_export.no_zip_extension'),
-				array('c' => 'importExport', 'a' => 'index'));
+			Minz_Request::bad(
+				_t('feedback.import_export.no_zip_extension'),
+				['c' => 'importExport', 'a' => 'index']
+			);
 		} catch (FreshRSS_Zip_Exception $ze) {
 			Minz_Log::warning('ZIP archive cannot be imported. Error code: ' . $ze->zipErrorCode());
-			Minz_Request::bad(_t('feedback.import_export.zip_error'),
-				array('c' => 'importExport', 'a' => 'index'));
+			Minz_Request::bad(
+				_t('feedback.import_export.zip_error'),
+				['c' => 'importExport', 'a' => 'index']
+			);
 		}
 
 		// And finally, we get import status and redirect to the home page
-		Minz_Session::_param('actualize_feeds', true);
 		$content_notif = $error === true ? _t('feedback.import_export.feeds_imported_with_errors') : _t('feedback.import_export.feeds_imported');
 		Minz_Request::good($content_notif);
 	}
@@ -190,7 +213,7 @@ class FreshRSS_importExport_Controller extends FreshRSS_ActionController {
 	 * It is a *very* basic guess file type function. Only based on filename.
 	 * That could be improved but should be enough for what we have to do.
 	 */
-	private static function guessFileType($filename) {
+	private static function guessFileType(string $filename): string {
 		if (substr_compare($filename, '.zip', -4) === 0) {
 			return 'zip';
 		} elseif (stripos($filename, 'opml') !== false) {
@@ -211,20 +234,23 @@ class FreshRSS_importExport_Controller extends FreshRSS_ActionController {
 		return 'unknown';
 	}
 
+	/**
+	 * @return false|string
+	 */
 	private function ttrssXmlToJson(string $xml) {
 		$table = (array)simplexml_load_string($xml, null, LIBXML_NOBLANKS | LIBXML_NOCDATA);
-		$table['items'] = isset($table['article']) ? $table['article'] : array();
+		$table['items'] = $table['article'] ?? [];
 		unset($table['article']);
 		for ($i = count($table['items']) - 1; $i >= 0; $i--) {
 			$item = (array)($table['items'][$i]);
-			$item = array_filter($item, function ($v) {
+			$item = array_filter($item, static function ($v) {
 					// Filter out empty properties, potentially reported as empty objects
 					return (is_string($v) && trim($v) !== '') || !empty($v);
 				});
 			$item['updated'] = isset($item['updated']) ? strtotime($item['updated']) : '';
 			$item['published'] = $item['updated'];
-			$item['content'] = array('content' => isset($item['content']) ? $item['content'] : '');
-			$item['categories'] = isset($item['tag_cache']) ? array($item['tag_cache']) : array();
+			$item['content'] = ['content' => $item['content'] ?? ''];
+			$item['categories'] = isset($item['tag_cache']) ? [$item['tag_cache']] : [];
 			if (!empty($item['marked'])) {
 				$item['categories'][] = 'user/-/state/com.google/starred';
 			}
@@ -241,12 +267,12 @@ class FreshRSS_importExport_Controller extends FreshRSS_ActionController {
 					}
 				}
 			}
-			$item['alternate'][0]['href'] = isset($item['link']) ? $item['link'] : '';
-			$item['origin'] = array(
-					'title' => isset($item['feed_title']) ? $item['feed_title'] : '',
-					'feedUrl' => isset($item['feed_url']) ? $item['feed_url'] : '',
-				);
-			$item['id'] = isset($item['guid']) ? $item['guid'] : (isset($item['feed_url']) ? $item['feed_url'] : $item['published']);
+			$item['alternate'][0]['href'] = $item['link'] ?? '';
+			$item['origin'] = [
+				'title' => $item['feed_title'] ?? '',
+				'feedUrl' => $item['feed_url'] ?? '',
+			];
+			$item['id'] = $item['guid'] ?? ($item['feed_url'] ?? $item['published']);
 			$item['guid'] = $item['id'];
 			$table['items'][$i] = $item;
 		}
@@ -256,11 +282,13 @@ class FreshRSS_importExport_Controller extends FreshRSS_ActionController {
 	/**
 	 * This method import a JSON-based file (Google Reader format).
 	 *
-	 * @param string $article_file the JSON file content.
-	 * @param boolean $starred true if articles from the file must be starred.
-	 * @return boolean false if an error occurred, true otherwise.
+	 * $article_file the JSON file content.
+	 * true if articles from the file must be starred.
+	 * @return bool false if an error occurred, true otherwise.
+	 * @throws Minz_ConfigurationNamespaceException
+	 * @throws Minz_PDOConnectionException
 	 */
-	private function importJson($article_file, $starred = false) {
+	private function importJson(string $article_file, bool $starred = false): bool {
 		$article_object = json_decode($article_file, true);
 		if ($article_object == null) {
 			if (FreshRSS_Context::$isCli) {
@@ -270,19 +298,19 @@ class FreshRSS_importExport_Controller extends FreshRSS_ActionController {
 			}
 			return false;
 		}
-		$items = isset($article_object['items']) ? $article_object['items'] : $article_object;
+		$items = $article_object['items'] ?? $article_object;
 
 		$mark_as_read = FreshRSS_Context::$user_conf->mark_when['reception'] ? 1 : 0;
 
 		$error = false;
-		$article_to_feed = array();
+		$article_to_feed = [];
 
 		$nb_feeds = count($this->feedDAO->listFeeds());
-		$newFeedGuids = array();
+		$newFeedGuids = [];
 		$limits = FreshRSS_Context::$system_conf->limits;
 
 		// First, we check feeds of articles are in DB (and add them if needed).
-		foreach ($items as $item) {
+		foreach ($items as &$item) {
 			if (!isset($item['guid']) && isset($item['id'])) {
 				$item['guid'] = $item['id'];
 			}
@@ -310,7 +338,7 @@ class FreshRSS_importExport_Controller extends FreshRSS_ActionController {
 			$feed = new FreshRSS_Feed($feedUrl);
 			$feed = $this->feedDAO->searchByUrl($feed->url());
 
-			if ($feed == null) {
+			if ($feed === null) {
 				// Feed does not exist in DB,we should to try to add it.
 				if ((!FreshRSS_Context::$isCli) && ($nb_feeds >= $limits['max_feeds'])) {
 					// Oops, no more place!
@@ -319,7 +347,7 @@ class FreshRSS_importExport_Controller extends FreshRSS_ActionController {
 					$feed = $this->addFeedJson($item['origin']);
 				}
 
-				if ($feed == null) {
+				if ($feed === null) {
 					// Still null? It means something went wrong.
 					$error = true;
 				} else {
@@ -330,43 +358,43 @@ class FreshRSS_importExport_Controller extends FreshRSS_ActionController {
 			if ($feed != null) {
 				$article_to_feed[$item['guid']] = $feed->id();
 				if (!isset($newFeedGuids['f_' . $feed->id()])) {
-					$newFeedGuids['f_' . $feed->id()] = array();
+					$newFeedGuids['f_' . $feed->id()] = [];
 				}
 				$newFeedGuids['f_' . $feed->id()][] = safe_ascii($item['guid']);
 			}
 		}
 
 		$tagDAO = FreshRSS_Factory::createTagDao();
-		$labels = $tagDAO->listTags();
-		$knownLabels = array();
+		$labels = $tagDAO->listTags() ?: [];
+		$knownLabels = [];
 		foreach ($labels as $label) {
 			$knownLabels[$label->name()]['id'] = $label->id();
-			$knownLabels[$label->name()]['articles'] = array();
+			$knownLabels[$label->name()]['articles'] = [];
 		}
 		unset($labels);
 
 		// For each feed, check existing GUIDs already in database.
-		$existingHashForGuids = array();
+		$existingHashForGuids = [];
 		foreach ($newFeedGuids as $feedId => $newGuids) {
-			$existingHashForGuids[$feedId] = $this->entryDAO->listHashForFeedGuids(substr($feedId, 2), $newGuids);
+			$existingHashForGuids[$feedId] = $this->entryDAO->listHashForFeedGuids((int)substr($feedId, 2), $newGuids);
 		}
 		unset($newFeedGuids);
 
 		// Then, articles are imported.
-		$newGuids = array();
+		$newGuids = [];
 		$this->entryDAO->beginTransaction();
-		foreach ($items as $item) {
+		foreach ($items as &$item) {
 			if (empty($item['guid']) || empty($article_to_feed[$item['guid']])) {
 				// Related feed does not exist for this entry, do nothing.
 				continue;
 			}
 
 			$feed_id = $article_to_feed[$item['guid']];
-			$author = isset($item['author']) ? $item['author'] : '';
+			$author = $item['author'] ?? '';
 			$is_starred = null; // null is used to preserve the current state if that item exists and is already starred
 			$is_read = null;
-			$tags = empty($item['categories']) ? array() : $item['categories'];
-			$labels = array();
+			$tags = empty($item['categories']) ? [] : $item['categories'];
+			$labels = [];
 			for ($i = count($tags) - 1; $i >= 0; $i--) {
 				$tag = trim($tags[$i]);
 				if (strpos($tag, 'user/-/') !== false) {
@@ -400,14 +428,17 @@ class FreshRSS_importExport_Controller extends FreshRSS_ActionController {
 			} else {
 				$url = '';
 			}
+			if (!is_string($url)) {
+				$url = '';
+			}
 
 			$title = empty($item['title']) ? $url : $item['title'];
 
-			if (!empty($item['content']['content'])) {
+			if (isset($item['content']['content']) && is_string($item['content']['content'])) {
 				$content = $item['content']['content'];
-			} elseif (!empty($item['summary']['content'])) {
+			} elseif (isset($item['summary']['content']) && is_string($item['summary']['content'])) {
 				$content = $item['summary']['content'];
-			} elseif (!empty($item['content'])) {
+			} elseif (isset($item['content']) && is_string($item['content'])) {
 				$content = $item['content'];	//FeedBin
 			} else {
 				$content = '';
@@ -442,32 +473,30 @@ class FreshRSS_importExport_Controller extends FreshRSS_ActionController {
 			}
 			$newGuids[$entry->guid()] = true;
 
-			/** @var FreshRSS_Entry|null */
 			$entry = Minz_ExtensionManager::callHook('entry_before_insert', $entry);
-			if ($entry == null) {
+			if (!($entry instanceof FreshRSS_Entry)) {
 				// An extension has returned a null value, there is nothing to insert.
 				continue;
 			}
 
-			$values = $entry->toArray();
-			$ok = false;
 			if (isset($existingHashForGuids['f_' . $feed_id][$entry->guid()])) {
-				$ok = $this->entryDAO->updateEntry($values);
+				$ok = $this->entryDAO->updateEntry($entry->toArray());
 			} else {
-				$ok = $this->entryDAO->addEntry($values);
+				$entry->_lastSeen(time());
+				$ok = $this->entryDAO->addEntry($entry->toArray());
 			}
 
 			foreach ($labels as $labelName) {
 				if (empty($knownLabels[$labelName]['id'])) {
-					$labelId = $tagDAO->addTag(array('name' => $labelName));
+					$labelId = $tagDAO->addTag(['name' => $labelName]);
 					$knownLabels[$labelName]['id'] = $labelId;
-					$knownLabels[$labelName]['articles'] = array();
+					$knownLabels[$labelName]['articles'] = [];
 				}
-				$knownLabels[$labelName]['articles'][] = array(
-						//'id' => $entry->id(),	//ID changes after commitNewEntries()
-						'id_feed' => $entry->feedId(),
-						'guid' => $entry->guid(),
-					);
+				$knownLabels[$labelName]['articles'][] = [
+					//'id' => $entry->id(),	//ID changes after commitNewEntries()
+					'id_feed' => $entry->feedId(),
+					'guid' => $entry->guid(),
+				];
 			}
 
 			$error |= ($ok === false);
@@ -505,7 +534,7 @@ class FreshRSS_importExport_Controller extends FreshRSS_ActionController {
 	 * @param array<string,string> $origin represents a feed.
 	 * @return FreshRSS_Feed|null if feed is in database at the end of the process, else null.
 	 */
-	private function addFeedJson($origin) {
+	private function addFeedJson(array $origin): ?FreshRSS_Feed {
 		$return = null;
 		if (!empty($origin['feedUrl'])) {
 			$url = $origin['feedUrl'];
@@ -567,61 +596,58 @@ class FreshRSS_importExport_Controller extends FreshRSS_ActionController {
 	 *   - export_labelled (default: false)
 	 *   - export_feeds (default: array()) a list of feed ids
 	 */
-	public function exportAction() {
+	public function exportAction(): void {
 		if (!Minz_Request::isPost()) {
-			return Minz_Request::forward(
-				array('c' => 'importExport', 'a' => 'index'),
-				true
-			);
+			Minz_Request::forward(['c' => 'importExport', 'a' => 'index'], true);
+			return;
 		}
 
-		$username = Minz_Session::param('currentUser');
+		$username = Minz_User::name();
 		$export_service = new FreshRSS_Export_Service($username);
 
-		$export_opml = Minz_Request::param('export_opml', false);
-		$export_starred = Minz_Request::param('export_starred', false);
-		$export_labelled = Minz_Request::param('export_labelled', false);
-		$export_feeds = Minz_Request::param('export_feeds', array());
+		$export_opml = Minz_Request::paramBoolean('export_opml');
+		$export_starred = Minz_Request::paramBoolean('export_starred');
+		$export_labelled = Minz_Request::paramBoolean('export_labelled');
+		/** @var array<numeric-string> */
+		$export_feeds = Minz_Request::paramArray('export_feeds');
 		$max_number_entries = 50;
 
 		$exported_files = [];
 
 		if ($export_opml) {
-			list($filename, $content) = $export_service->generateOpml();
+			[$filename, $content] = $export_service->generateOpml();
 			$exported_files[$filename] = $content;
 		}
 
 		// Starred and labelled entries are merged in the same `starred` file
 		// to avoid duplication of content.
 		if ($export_starred && $export_labelled) {
-			list($filename, $content) = $export_service->generateStarredEntries('ST');
+			[$filename, $content] = $export_service->generateStarredEntries('ST');
 			$exported_files[$filename] = $content;
 		} elseif ($export_starred) {
-			list($filename, $content) = $export_service->generateStarredEntries('S');
+			[$filename, $content] = $export_service->generateStarredEntries('S');
 			$exported_files[$filename] = $content;
 		} elseif ($export_labelled) {
-			list($filename, $content) = $export_service->generateStarredEntries('T');
+			[$filename, $content] = $export_service->generateStarredEntries('T');
 			$exported_files[$filename] = $content;
 		}
 
 		foreach ($export_feeds as $feed_id) {
-			$result = $export_service->generateFeedEntries($feed_id, $max_number_entries);
+			$result = $export_service->generateFeedEntries((int)$feed_id, $max_number_entries);
 			if (!$result) {
 				// It means the actual feed_id doesn’t correspond to any existing feed
 				continue;
 			}
 
-			list($filename, $content) = $result;
+			[$filename, $content] = $result;
 			$exported_files[$filename] = $content;
 		}
 
 		$nb_files = count($exported_files);
 		if ($nb_files <= 0) {
-			// There’s nothing to do, there’re no files to export
-			return Minz_Request::forward(
-				array('c' => 'importExport', 'a' => 'index'),
-				true
-			);
+			// There’s nothing to do, there are no files to export
+			Minz_Request::forward(['c' => 'importExport', 'a' => 'index'], true);
+			return;
 		}
 
 		if ($nb_files === 1) {
@@ -632,20 +658,26 @@ class FreshRSS_importExport_Controller extends FreshRSS_ActionController {
 			// More files? Let’s compress them in a Zip archive
 			if (!extension_loaded('zip')) {
 				// Oops, there is no ZIP extension!
-				return Minz_Request::bad(
+				Minz_Request::bad(
 					_t('feedback.import_export.export_no_zip_extension'),
-					array('c' => 'importExport', 'a' => 'index')
+					['c' => 'importExport', 'a' => 'index']
 				);
+				return;
 			}
 
-			list($filename, $content) = $export_service->zip($exported_files);
+			[$filename, $content] = $export_service->zip($exported_files);
+		}
+
+		if (!is_string($content)) {
+			Minz_Request::bad(_t('feedback.import_export.zip_error'), ['c' => 'importExport', 'a' => 'index']);
+			return;
 		}
 
 		$content_type = self::filenameToContentType($filename);
 		header('Content-Type: ' . $content_type);
 		header('Content-disposition: attachment; filename="' . $filename . '"');
 
-		$this->view->_layout(false);
+		$this->view->_layout(null);
 		$this->view->content = $content;
 	}
 
@@ -654,12 +686,8 @@ class FreshRSS_importExport_Controller extends FreshRSS_ActionController {
 	 *
 	 * If the type of the filename is not supported, it returns
 	 * `application/octet-stream` by default.
-	 *
-	 * @param string $filename
-	 *
-	 * @return string
 	 */
-	private static function filenameToContentType($filename) {
+	private static function filenameToContentType(string $filename): string {
 		$filetype = self::guessFileType($filename);
 		switch ($filetype) {
 		case 'zip':
