@@ -7,10 +7,11 @@ class FreshRSS_User_Mailer extends Minz_Mailer {
 
 	/**
 	 * @var FreshRSS_View
+	 * @phpstan-ignore-next-line
 	 */
 	protected $view;
 
-	public function send_email_need_validation($username, $user_config) {
+	public function send_email_need_validation(string $username, FreshRSS_UserConfiguration $user_config): bool {
 		Minz_Translate::reset($user_config->language);
 
 		$this->view->_path('user_mailer/email_need_validation.txt.php');
@@ -18,14 +19,14 @@ class FreshRSS_User_Mailer extends Minz_Mailer {
 		$this->view->username = $username;
 		$this->view->site_title = FreshRSS_Context::$system_conf->title;
 		$this->view->validation_url = Minz_Url::display(
-			array(
+			[
 				'c' => 'user',
 				'a' => 'validateEmail',
-				'params' => array(
+				'params' => [
 					'username' => $username,
-					'token' => $user_config->email_validation_token
-				)
-			),
+					'token' => $user_config->email_validation_token,
+				],
+			],
 			'txt',
 			true
 		);
