@@ -10,45 +10,70 @@ require_once(LIB_PATH . '/lib_date.php');
  */
 class FreshRSS_Search {
 
-	// This contains the user input string
+	/**
+	 * This contains the user input string
+	 * @var string
+	 */
 	private $raw_input = '';
 
 	// The following properties are extracted from the raw input
+	/** @var array<string>|null */
 	private $entry_ids;
+	/** @var array<int>|null */
 	private $feed_ids;
+	/** @var array<int>|'*'|null */
 	private $label_ids;
+	/** @var array<string>|null */
 	private $label_names;
+	/** @var array<string>|null */
 	private $intitle;
+	/** @var int|false|null */
 	private $min_date;
+	/** @var int|false|null */
 	private $max_date;
+	/** @var int|false|null */
 	private $min_pubdate;
+	/** @var int|false|null */
 	private $max_pubdate;
+	/** @var array<string>|null */
 	private $inurl;
+	/** @var array<string>|null */
 	private $author;
+	/** @var array<string>|null */
 	private $tags;
+	/** @var array<string>|null */
 	private $search;
 
+	/** @var array<string>|null */
 	private $not_entry_ids;
+	/** @var array<int>|null */
 	private $not_feed_ids;
+	/** @var array<int>|'*'|null */
 	private $not_label_ids;
+	/** @var array<string>|null */
 	private $not_label_names;
+	/** @var array<string>|null */
 	private $not_intitle;
+	/** @var int|false|null */
 	private $not_min_date;
+	/** @var int|false|null */
 	private $not_max_date;
+	/** @var int|false|null */
 	private $not_min_pubdate;
+	/** @var int|false|null */
 	private $not_max_pubdate;
+	/** @var array<string>|null */
 	private $not_inurl;
+	/** @var array<string>|null */
 	private $not_author;
+	/** @var array<string>|null */
 	private $not_tags;
+	/** @var array<string>|null */
 	private $not_search;
 
-	/**
-	 * @param string|null $input
-	 */
-	public function __construct($input) {
-		if ($input == '') {
-			return;
-		}
+	public function __construct(string $input) {
+		$input = self::cleanSearch($input);
+		$input = self::unescape($input);
 		$this->raw_input = $input;
 
 		$input = $this->parseNotEntryIds($input);
@@ -82,114 +107,142 @@ class FreshRSS_Search {
 		$this->parseSearch($input);
 	}
 
-	public function __toString() {
+	public function __toString(): string {
 		return $this->getRawInput();
 	}
 
-	public function getRawInput() {
+	public function getRawInput(): string {
 		return $this->raw_input;
 	}
 
-	public function getEntryIds() {
+	/** @return array<string>|null */
+	public function getEntryIds(): ?array {
 		return $this->entry_ids;
 	}
-	public function getNotEntryIds() {
+	/** @return array<string>|null */
+	public function getNotEntryIds(): ?array {
 		return $this->not_entry_ids;
 	}
 
-	public function getFeedIds() {
+	/** @return array<int>|null */
+	public function getFeedIds(): ?array {
 		return $this->feed_ids;
 	}
-	public function getNotFeedIds() {
+	/** @return array<int>|null */
+	public function getNotFeedIds(): ?array {
 		return $this->not_feed_ids;
 	}
 
+	/** @return array<int>|'*'|null */
 	public function getLabelIds() {
 		return $this->label_ids;
 	}
-	public function getNotlabelIds() {
+	/** @return array<int>|'*'|null */
+	public function getNotLabelIds() {
 		return $this->not_label_ids;
 	}
-	public function getLabelNames() {
+	/** @return array<string>|null */
+	public function getLabelNames(): ?array {
 		return $this->label_names;
 	}
-	public function getNotlabelNames() {
+	/** @return array<string>|null */
+	public function getNotLabelNames(): ?array {
 		return $this->not_label_names;
 	}
 
-	public function getIntitle() {
+	/** @return array<string>|null */
+	public function getIntitle(): ?array {
 		return $this->intitle;
 	}
-	public function getNotIntitle() {
+	/** @return array<string>|null */
+	public function getNotIntitle(): ?array {
 		return $this->not_intitle;
 	}
 
-	public function getMinDate() {
-		return $this->min_date;
+	public function getMinDate(): ?int {
+		return $this->min_date ?: null;
 	}
-	public function getNotMinDate() {
-		return $this->not_min_date;
+	public function getNotMinDate(): ?int {
+		return $this->not_min_date ?: null;
 	}
-	public function setMinDate($value) {
-		return $this->min_date = $value;
+	public function setMinDate(int $value): void {
+		$this->min_date = $value;
 	}
 
-	public function getMaxDate() {
-		return $this->max_date;
+	public function getMaxDate(): ?int {
+		return $this->max_date ?: null;
 	}
-	public function getNotMaxDate() {
-		return $this->not_max_date;
+	public function getNotMaxDate(): ?int {
+		return $this->not_max_date ?: null;
 	}
-	public function setMaxDate($value) {
-		return $this->max_date = $value;
+	public function setMaxDate(int $value): void {
+		$this->max_date = $value;
 	}
 
-	public function getMinPubdate() {
-		return $this->min_pubdate;
+	public function getMinPubdate(): ?int {
+		return $this->min_pubdate ?: null;
 	}
-	public function getNotMinPubdate() {
-		return $this->not_min_pubdate;
+	public function getNotMinPubdate(): ?int {
+		return $this->not_min_pubdate ?: null;
 	}
 
-	public function getMaxPubdate() {
-		return $this->max_pubdate;
+	public function getMaxPubdate(): ?int {
+		return $this->max_pubdate ?: null;
 	}
-	public function getNotMaxPubdate() {
-		return $this->not_max_pubdate;
+	public function getNotMaxPubdate(): ?int {
+		return $this->not_max_pubdate ?: null;
 	}
 
-	public function getInurl() {
+	/** @return array<string>|null */
+	public function getInurl(): ?array {
 		return $this->inurl;
 	}
-	public function getNotInurl() {
+	/** @return array<string>|null */
+	public function getNotInurl(): ?array {
 		return $this->not_inurl;
 	}
 
-	public function getAuthor() {
+	/** @return array<string>|null */
+	public function getAuthor(): ?array {
 		return $this->author;
 	}
-	public function getNotAuthor() {
+	/** @return array<string>|null */
+	public function getNotAuthor(): ?array {
 		return $this->not_author;
 	}
 
-	public function getTags() {
+	/** @return array<string>|null */
+	public function getTags(): ?array {
 		return $this->tags;
 	}
-	public function getNotTags() {
+	/** @return array<string>|null */
+	public function getNotTags(): ?array {
 		return $this->not_tags;
 	}
 
-	public function getSearch() {
+	/** @return array<string>|null */
+	public function getSearch(): ?array {
 		return $this->search;
 	}
-	public function getNotSearch() {
+	/** @return array<string>|null */
+	public function getNotSearch(): ?array {
 		return $this->not_search;
 	}
 
-	private static function removeEmptyValues($anArray) {
-		return is_array($anArray) ? array_filter($anArray, function($value) { return $value !== ''; }) : array();
+	/**
+	 * @param array<string>|null $anArray
+	 * @return array<string>
+	 */
+	private static function removeEmptyValues(?array $anArray): array {
+		return empty($anArray) ? [] : array_filter($anArray, static function(string $value) {
+			return $value !== '';
+		});
 	}
 
+	/**
+	 * @param array<string>|string $value
+	 * @return ($value is array ? array<string> : string)
+	 */
 	private static function decodeSpaces($value) {
 		if (is_array($value)) {
 			for ($i = count($value) - 1; $i >= 0; $i--) {
@@ -213,7 +266,7 @@ class FreshRSS_Search {
 				$entry_ids = explode(',', $ids_list);
 				$entry_ids = self::removeEmptyValues($entry_ids);
 				if (!empty($entry_ids)) {
-					$this->entry_ids[] = $entry_ids;
+					$this->entry_ids = array_merge($this->entry_ids, $entry_ids);
 				}
 			}
 		}
@@ -229,7 +282,7 @@ class FreshRSS_Search {
 				$entry_ids = explode(',', $ids_list);
 				$entry_ids = self::removeEmptyValues($entry_ids);
 				if (!empty($entry_ids)) {
-					$this->not_entry_ids[] = $entry_ids;
+					$this->not_entry_ids = array_merge($this->not_entry_ids, $entry_ids);
 				}
 			}
 		}
@@ -244,8 +297,10 @@ class FreshRSS_Search {
 			foreach ($ids_lists as $ids_list) {
 				$feed_ids = explode(',', $ids_list);
 				$feed_ids = self::removeEmptyValues($feed_ids);
+				/** @var array<int> $feed_ids */
+				$feed_ids = array_map('intval', $feed_ids);
 				if (!empty($feed_ids)) {
-					$this->feed_ids[] = $feed_ids;
+					$this->feed_ids = array_merge($this->feed_ids, $feed_ids);
 				}
 			}
 		}
@@ -260,8 +315,10 @@ class FreshRSS_Search {
 			foreach ($ids_lists as $ids_list) {
 				$feed_ids = explode(',', $ids_list);
 				$feed_ids = self::removeEmptyValues($feed_ids);
+				/** @var array<int> $feed_ids */
+				$feed_ids = array_map('intval', $feed_ids);
 				if (!empty($feed_ids)) {
-					$this->not_feed_ids[] = $feed_ids;
+					$this->not_feed_ids = array_merge($this->not_feed_ids, $feed_ids);
 				}
 			}
 		}
@@ -278,13 +335,15 @@ class FreshRSS_Search {
 			$this->label_ids = [];
 			foreach ($ids_lists as $ids_list) {
 				if ($ids_list === '*') {
-					$this->label_ids[] = '*';
+					$this->label_ids = '*';
 					break;
 				}
 				$label_ids = explode(',', $ids_list);
 				$label_ids = self::removeEmptyValues($label_ids);
+				/** @var array<int> $label_ids */
+				$label_ids = array_map('intval', $label_ids);
 				if (!empty($label_ids)) {
-					$this->label_ids[] = $label_ids;
+					$this->label_ids = array_merge($this->label_ids, $label_ids);
 				}
 			}
 		}
@@ -298,13 +357,15 @@ class FreshRSS_Search {
 			$this->not_label_ids = [];
 			foreach ($ids_lists as $ids_list) {
 				if ($ids_list === '*') {
-					$this->not_label_ids[] = '*';
+					$this->not_label_ids = '*';
 					break;
 				}
 				$label_ids = explode(',', $ids_list);
 				$label_ids = self::removeEmptyValues($label_ids);
+				/** @var array<int> $label_ids */
+				$label_ids = array_map('intval', $label_ids);
 				if (!empty($label_ids)) {
-					$this->not_label_ids[] = $label_ids;
+					$this->not_label_ids = array_merge($this->not_label_ids, $label_ids);
 				}
 			}
 		}
@@ -330,7 +391,7 @@ class FreshRSS_Search {
 				$names_array = explode(',', $names_list);
 				$names_array = self::removeEmptyValues($names_array);
 				if (!empty($names_array)) {
-					$this->label_names[] = $names_array;
+					$this->label_names = array_merge($this->label_names, $names_array);
 				}
 			}
 		}
@@ -356,7 +417,7 @@ class FreshRSS_Search {
 				$names_array = explode(',', $names_list);
 				$names_array = self::removeEmptyValues($names_array);
 				if (!empty($names_array)) {
-					$this->not_label_names[] = $names_array;
+					$this->not_label_names = array_merge($this->not_label_names, $names_array);
 				}
 			}
 		}
@@ -373,10 +434,13 @@ class FreshRSS_Search {
 			$input = str_replace($matches[0], '', $input);
 		}
 		if (preg_match_all('/\bintitle:(?P<search>[^\s"]*)/', $input, $matches)) {
-			$this->intitle = array_merge($this->intitle ? $this->intitle : array(), $matches['search']);
+			$this->intitle = array_merge($this->intitle ?: [], $matches['search']);
 			$input = str_replace($matches[0], '', $input);
 		}
 		$this->intitle = self::removeEmptyValues($this->intitle);
+		if (empty($this->intitle)) {
+			$this->intitle = null;
+		}
 		return $input;
 	}
 
@@ -386,10 +450,13 @@ class FreshRSS_Search {
 			$input = str_replace($matches[0], '', $input);
 		}
 		if (preg_match_all('/(?<=\s|^)[!-]intitle:(?P<search>[^\s"]*)/', $input, $matches)) {
-			$this->not_intitle = array_merge($this->not_intitle ? $this->not_intitle : array(), $matches['search']);
+			$this->not_intitle = array_merge($this->not_intitle ?: [], $matches['search']);
 			$input = str_replace($matches[0], '', $input);
 		}
 		$this->not_intitle = self::removeEmptyValues($this->not_intitle);
+		if (empty($this->not_intitle)) {
+			$this->not_intitle = null;
+		}
 		return $input;
 	}
 
@@ -404,10 +471,13 @@ class FreshRSS_Search {
 			$input = str_replace($matches[0], '', $input);
 		}
 		if (preg_match_all('/\bauthor:(?P<search>[^\s"]*)/', $input, $matches)) {
-			$this->author = array_merge($this->author ? $this->author : array(), $matches['search']);
+			$this->author = array_merge($this->author ?: [], $matches['search']);
 			$input = str_replace($matches[0], '', $input);
 		}
 		$this->author = self::removeEmptyValues($this->author);
+		if (empty($this->author)) {
+			$this->author = null;
+		}
 		return $input;
 	}
 
@@ -417,10 +487,13 @@ class FreshRSS_Search {
 			$input = str_replace($matches[0], '', $input);
 		}
 		if (preg_match_all('/(?<=\s|^)[!-]author:(?P<search>[^\s"]*)/', $input, $matches)) {
-			$this->not_author = array_merge($this->not_author ? $this->not_author : array(), $matches['search']);
+			$this->not_author = array_merge($this->not_author ?: [], $matches['search']);
 			$input = str_replace($matches[0], '', $input);
 		}
 		$this->not_author = self::removeEmptyValues($this->not_author);
+		if (empty($this->not_author)) {
+			$this->not_author = null;
+		}
 		return $input;
 	}
 
@@ -432,8 +505,8 @@ class FreshRSS_Search {
 		if (preg_match_all('/\binurl:(?P<search>[^\s]*)/', $input, $matches)) {
 			$this->inurl = $matches['search'];
 			$input = str_replace($matches[0], '', $input);
+			$this->inurl = self::removeEmptyValues($this->inurl);
 		}
-		$this->inurl = self::removeEmptyValues($this->inurl);
 		return $input;
 	}
 
@@ -441,8 +514,8 @@ class FreshRSS_Search {
 		if (preg_match_all('/(?<=\s|^)[!-]inurl:(?P<search>[^\s]*)/', $input, $matches)) {
 			$this->not_inurl = $matches['search'];
 			$input = str_replace($matches[0], '', $input);
+			$this->not_inurl = self::removeEmptyValues($this->not_inurl);
 		}
-		$this->not_inurl = self::removeEmptyValues($this->not_inurl);
 		return $input;
 	}
 
@@ -455,7 +528,7 @@ class FreshRSS_Search {
 			$input = str_replace($matches[0], '', $input);
 			$dates = self::removeEmptyValues($matches['search']);
 			if (!empty($dates[0])) {
-				list($this->min_date, $this->max_date) = parseDateInterval($dates[0]);
+				[$this->min_date, $this->max_date] = parseDateInterval($dates[0]);
 			}
 		}
 		return $input;
@@ -466,7 +539,7 @@ class FreshRSS_Search {
 			$input = str_replace($matches[0], '', $input);
 			$dates = self::removeEmptyValues($matches['search']);
 			if (!empty($dates[0])) {
-				list($this->not_min_date, $this->not_max_date) = parseDateInterval($dates[0]);
+				[$this->not_min_date, $this->not_max_date] = parseDateInterval($dates[0]);
 			}
 		}
 		return $input;
@@ -482,7 +555,7 @@ class FreshRSS_Search {
 			$input = str_replace($matches[0], '', $input);
 			$dates = self::removeEmptyValues($matches['search']);
 			if (!empty($dates[0])) {
-				list($this->min_pubdate, $this->max_pubdate) = parseDateInterval($dates[0]);
+				[$this->min_pubdate, $this->max_pubdate] = parseDateInterval($dates[0]);
 			}
 		}
 		return $input;
@@ -493,7 +566,7 @@ class FreshRSS_Search {
 			$input = str_replace($matches[0], '', $input);
 			$dates = self::removeEmptyValues($matches['search']);
 			if (!empty($dates[0])) {
-				list($this->not_min_pubdate, $this->not_max_pubdate) = parseDateInterval($dates[0]);
+				[$this->not_min_pubdate, $this->not_max_pubdate] = parseDateInterval($dates[0]);
 			}
 		}
 		return $input;
@@ -508,9 +581,9 @@ class FreshRSS_Search {
 		if (preg_match_all('/#(?P<search>[^\s]+)/', $input, $matches)) {
 			$this->tags = $matches['search'];
 			$input = str_replace($matches[0], '', $input);
+			$this->tags = self::removeEmptyValues($this->tags);
+			$this->tags = self::decodeSpaces($this->tags);
 		}
-		$this->tags = self::removeEmptyValues($this->tags);
-		$this->tags = self::decodeSpaces($this->tags);
 		return $input;
 	}
 
@@ -518,9 +591,9 @@ class FreshRSS_Search {
 		if (preg_match_all('/(?<=\s|^)[!-]#(?P<search>[^\s]+)/', $input, $matches)) {
 			$this->not_tags = $matches['search'];
 			$input = str_replace($matches[0], '', $input);
+			$this->not_tags = self::removeEmptyValues($this->not_tags);
+			$this->not_tags = self::decodeSpaces($this->not_tags);
 		}
-		$this->not_tags = self::removeEmptyValues($this->not_tags);
-		$this->not_tags = self::decodeSpaces($this->not_tags);
 		return $input;
 	}
 
@@ -531,7 +604,7 @@ class FreshRSS_Search {
 	 */
 	private function parseQuotedSearch(string $input): string {
 		$input = self::cleanSearch($input);
-		if ($input == '') {
+		if ($input === '') {
 			return '';
 		}
 		if (preg_match_all('/(?<![!-])(?P<delim>[\'"])(?P<search>.*)(?P=delim)/U', $input, $matches)) {
@@ -548,7 +621,7 @@ class FreshRSS_Search {
 	 */
 	private function parseSearch(string $input): string {
 		$input = self::cleanSearch($input);
-		if ($input == '') {
+		if ($input === '') {
 			return '';
 		}
 		if (is_array($this->search)) {
@@ -561,7 +634,7 @@ class FreshRSS_Search {
 
 	private function parseNotSearch(string $input): string {
 		$input = self::cleanSearch($input);
-		if ($input == '') {
+		if ($input === '') {
 			return '';
 		}
 		if (preg_match_all('/(?<=\s|^)[!-](?P<delim>[\'"])(?P<search>.*)(?P=delim)/U', $input, $matches)) {
@@ -569,11 +642,11 @@ class FreshRSS_Search {
 			$input = str_replace($matches[0], '', $input);
 		}
 		$input = self::cleanSearch($input);
-		if ($input == '') {
+		if ($input === '') {
 			return '';
 		}
 		if (preg_match_all('/(?<=\s|^)[!-](?P<search>[^\s]+)/', $input, $matches)) {
-			$this->not_search = array_merge(is_array($this->not_search) ? $this->not_search : array(), $matches['search']);
+			$this->not_search = array_merge(is_array($this->not_search) ? $this->not_search : [], $matches['search']);
 			$input = str_replace($matches[0], '', $input);
 		}
 		$this->not_search = self::removeEmptyValues($this->not_search);
@@ -585,6 +658,14 @@ class FreshRSS_Search {
 	 */
 	private static function cleanSearch(string $input): string {
 		$input = preg_replace('/\s+/', ' ', $input);
+		if (!is_string($input)) {
+			return '';
+		}
 		return trim($input);
 	}
+
+	/** Remove escaping backslashes for parenthesis logic */
+	private static function unescape(string $input): string {
+		return str_replace(['\\(', '\\)'], ['(', ')'], $input);
+	}
 }
