@@ -5,21 +5,14 @@ interface I18nValidatorInterface {
 	/**
 	 * Display the validation result.
 	 * Empty if there are no errors.
-	 *
-	 * @return array
 	 */
-	public function displayResult();
+	public function displayResult(): string;
 
-	/**
-	 * @return bool
-	 */
-	public function validate();
+	public function validate(): bool;
 
 	/**
 	 * Display the validation report.
-	 *
-	 * @return string
 	 */
-	public function displayReport();
+	public function displayReport(): string;
 
 }
