@@ -1,16 +1,18 @@
 <?php
 
 class I18nValue {
-	const STATE_DIRTY = 'dirty';
-	const STATE_IGNORE = 'ignore';
-	const STATE_TODO = 'todo';
-	const STATES = [
+	private const STATE_DIRTY = 'dirty';
+	public const STATE_IGNORE = 'ignore';
+	private const STATE_TODO = 'todo';
+	private const STATES = [
 		self::STATE_DIRTY,
 		self::STATE_IGNORE,
 		self::STATE_TODO,
 	];
 
+	/** @var string */
 	private $value;
+	/**	@var string|null */
 	private $state;
 
 	public function __construct(string $data) {
@@ -22,7 +24,7 @@ class I18nValue {
 		}
 
 		$state = array_shift($data);
-		if (in_array($state, self::STATES)) {
+		if (in_array($state, self::STATES, true)) {
 			$this->state = $state;
 		}
 	}
@@ -31,37 +33,37 @@ class I18nValue {
 		$this->markAsTodo();
 	}
 
-	public function equal(I18nValue $value) {
+	public function equal(I18nValue $value): bool {
 		return $this->value === $value->getValue();
 	}
 
-	public function isIgnore() {
+	public function isIgnore(): bool {
 		return $this->state === self::STATE_IGNORE;
 	}
 
-	public function isTodo() {
+	public function isTodo(): bool {
 		return $this->state === self::STATE_TODO;
 	}
 
-	public function markAsDirty() {
+	public function markAsDirty(): void {
 		$this->state = self::STATE_DIRTY;
 	}
 
-	public function markAsIgnore() {
+	public function markAsIgnore(): void {
 		$this->state = self::STATE_IGNORE;
 	}
 
-	public function markAsTodo() {
+	public function markAsTodo(): void {
 		$this->state = self::STATE_TODO;
 	}
 
-	public function unmarkAsIgnore() {
+	public function unmarkAsIgnore(): void {
 		if ($this->state === self::STATE_IGNORE) {
 			$this->state = null;
 		}
 	}
 
-	public function __toString() {
+	public function __toString(): string {
 		if ($this->state === null) {
 			return $this->value;
 		}
@@ -69,7 +71,7 @@ class I18nValue {
 		return "{$this->value} -> {$this->state}";
 	}
 
-	public function getValue() {
+	public function getValue(): string {
 		return $this->value;
 	}
 }
