@@ -1,6 +1,6 @@
 <?php
 class Minz_ActionException extends Minz_Exception {
-	public function __construct ($controller_name, $action_name, $code = self::ERROR) {
+	public function __construct(string $controller_name, string $action_name, int $code = self::ERROR) {
 		// Just for security, as we are not supposed to get non-alphanumeric characters.
 		$action_name = rawurlencode($action_name);
 
