@@ -1,7 +1,7 @@
 <?php
 class Minz_CurrentPagePaginationException extends Minz_Exception {
-	public function __construct ($page) {
-		$message = 'Page number `' . $page . '` doesn\'t exist';
+	public function __construct(int $page) {
+		$message = 'Page number `' . $page . '` doesn’t exist';
 
 		parent::__construct ($message, self::ERROR);
 	}
