@@ -6,7 +6,8 @@
  */
 
 class Minz_PdoMysql extends Minz_Pdo {
-	public function __construct(string $dsn, $username = null, $passwd = null, $options = null) {
+	/** @param array<int,int|string|bool>|null $options */
+	public function __construct(string $dsn, ?string $username = null, ?string $passwd = null, ?array $options = null) {
 		parent::__construct($dsn, $username, $passwd, $options);
 		$this->setAttribute(PDO::MYSQL_ATTR_USE_BUFFERED_QUERY, false);
 	}
@@ -15,7 +16,10 @@ class Minz_PdoMysql extends Minz_Pdo {
 		return 'mysql';
 	}
 
-	// PHP8+: PDO::lastInsertId(?string $name = null): string|false
+	/**
+	 * @param string|null $name
+	 * @return string|false
+	 */
 	#[\ReturnTypeWillChange]
 	public function lastInsertId($name = null) {
 		return parent::lastInsertId();	//We discard the name, only used by PostgreSQL
