@@ -6,7 +6,8 @@
  */
 
 class Minz_PdoPgsql extends Minz_Pdo {
-	public function __construct(string $dsn, $username = null, $passwd = null, $options = null) {
+	/** @param array<int,int|string|bool>|null $options */
+	public function __construct(string $dsn, ?string $username = null, ?string $passwd = null, ?array $options = null) {
 		parent::__construct($dsn, $username, $passwd, $options);
 		$this->exec("SET NAMES 'UTF8';");
 	}
