@@ -1,27 +1,27 @@
 <?php
 
 class passwordUtilTest extends PHPUnit\Framework\TestCase {
-	public function testCheck() {
+	public function testCheck(): void {
 		$password = '1234567';
 
 		$ok = FreshRSS_password_Util::check($password);
 
-		$this->assertTrue($ok);
+		self::assertTrue($ok);
 	}
 
-	public function testCheckReturnsFalseIfEmpty() {
+	public function testCheckReturnsFalseIfEmpty(): void {
 		$password = '';
 
 		$ok = FreshRSS_password_Util::check($password);
 
-		$this->assertFalse($ok);
+		self::assertFalse($ok);
 	}
 
-	public function testCheckReturnsFalseIfLessThan7Characters() {
+	public function testCheckReturnsFalseIfLessThan7Characters(): void {
 		$password = '123456';
 
 		$ok = FreshRSS_password_Util::check($password);
 
-		$this->assertFalse($ok);
+		self::assertFalse($ok);
 	}
 }
