@@ -3,7 +3,7 @@
 require_once __DIR__ . '/../../../cli/i18n/I18nFile.php';
 
 class I18nFileTest extends PHPUnit\Framework\TestCase {
-	public function test() {
+	public function test(): void {
 		$before = $this->computeFilesHash();
 
 		$file = new I18nFile();
@@ -12,10 +12,11 @@ class I18nFileTest extends PHPUnit\Framework\TestCase {
 
 		$after = $this->computeFilesHash();
 
-		$this->assertEquals($before, $after);
+		self::assertEquals($before, $after);
 	}
 
-	private function computeFilesHash() {
+	/** @return array<string,string|false> */
+	private function computeFilesHash(): array {
 		$hashes = [];
 
 		$dirs = new DirectoryIterator(I18N_PATH);
@@ -29,7 +30,7 @@ class I18nFileTest extends PHPUnit\Framework\TestCase {
 					continue;
 				}
 
-				$hashes[$file->getPathName()] = sha1_file($file->getPathName());
+				$hashes[$file->getPathname()] = sha1_file($file->getPathname());
 			}
 		}
 
